#[non_exhaustive]pub enum GraphError {
Cyclic,
IncompatiblePorts,
InvalidCapacity,
InvalidEdgeIndex,
OccupancySampleFailed(EdgeIndex),
}Expand description
Graph validation and wiring errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cyclic
The graph contains a cycle.
IncompatiblePorts
Port schema or memory placement is incompatible across an edge.
InvalidCapacity
Queue capacity or watermark configuration is invalid.
InvalidEdgeIndex
Invalid graph index used.
OccupancySampleFailed(EdgeIndex)
Failed to sample occupancy for the given edge (e.g., poisoned lock or device error).