#[non_exhaustive]pub enum MemoryError {
NoFreeSlots,
BadToken,
NotAllocated,
AlreadyBorrowed,
BorrowActive,
Poisoned,
}Expand description
Errors originating from memory manager operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoFreeSlots
No free slots available in the manager.
BadToken
Token index is out of range (invalid token) or the slot is not allocated.
NotAllocated
Attempted to free a slot that is not currently allocated.
AlreadyBorrowed
Attempted to borrow (read or write) but slot is already borrowed in an incompatible way.
BorrowActive
Attempted to free a slot while borrows are still active.
Poisoned
A synchronization primitive (lock) was poisoned.