#[non_exhaustive]pub enum QueueError {
AtOrAboveHardCap,
Backpressured,
Empty,
Unsupported,
Poisoned,
}Expand description
Errors originating from queue operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AtOrAboveHardCap
The queue is at or above the hard watermark capacity.
Backpressured
The queue is backpressured but not full; caller may retry later.
Empty
The queue is empty when a pop operation was requested.
Unsupported
The operation is not supported by this queue/backend (e.g., reference peek in concurrent mode).
Poisoned
The queue lock has been poisoned (concurrent mode only).