NodeError

Struct NodeError 

#[non_exhaustive]
pub struct NodeError { /* private fields */ }
A unified error used by node lifecycle methods.

Implementations

Source

impl NodeError

pub const fn new(kind: NodeErrorKind, code: u32) -> Self

Construct a new node error with the given kind and optional code.

Source

impl NodeError

pub const fn no_input() -> Self

Creates a NoInput error.

pub const fn backpressured() -> Self

Creates a Backpressured error.

pub const fn over_budget() -> Self

Creates an OverBudget error.

pub const fn external_unavailable() -> Self

Creates an ExternalUnavailable error.

pub const fn execution_failed() -> Self

Creates an ExecutionFailed error.

pub const fn with_code(self, code: u32) -> Self

Same as the above but lets you tack on a backend/platform error code.

pub const fn kind(&self) -> &NodeErrorKind

Return the error kind.

pub const fn code(&self) -> &u32

Return the numeric code associated with this error.