#[non_exhaustive]pub enum StepResult {
MadeProgress,
NoInput,
Backpressured,
WaitingOnExternal,
YieldUntil(Ticks),
Terminal,
}Expand description
Result of a step call indicating progress and scheduling hints.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MadeProgress
Work was performed (messages consumed and/or produced).
NoInput
No inputs were available to make progress.
Backpressured
Backpressure prevented progress.
WaitingOnExternal
Waiting on external completion (device, transport).
YieldUntil(Ticks)
Yield until provided tick (cooperative scheduling hint).
Terminal
Node has completed and will not produce further outputs.