ConcurrentIngressEdgeLink

Struct ConcurrentIngressEdgeLink 

pub struct ConcurrentIngressEdgeLink<OutP: Payload> { /* private fields */ }
Link wrapper for a concurrent ingress monitor edge (std-only).

Implementations

Source

impl<OutP: Payload> ConcurrentIngressEdgeLink<OutP>

pub fn from_probe( probe_edge: SourceIngressProbeEdge<OutP>, id: EdgeIndex, upstream: PortId, downstream: PortId, policy: EdgePolicy, name: Option<&'static str>, ) -> Self

Construct a concurrent ingress edge link from a probe-backed edge and its descriptor metadata.

pub fn descriptor(&self) -> EdgeDescriptor

Return the descriptor for this synthetic ingress edge.

pub fn policy(&self) -> EdgePolicy

Return the policy associated with this synthetic ingress edge.

pub fn inner(&self) -> &SourceIngressProbeEdge<OutP>

Borrow the inner probe-backed edge immutably.

pub fn inner_mut(&mut self) -> &mut SourceIngressProbeEdge<OutP>

Borrow the inner probe-backed edge mutably.