OutStepContext

Struct OutStepContext 

pub struct OutStepContext<'graph, 'ctx, 'clock, const OUT: usize, OutP, OutQ, OutM, C, T>
where OutP: Payload, C: PlatformClock + Sized, T: Telemetry + Sized,
{ /* private fields */ }
A StepContext view that only exposes outputs / managers / clock / telemetry.

Explicitly does not provide access to input queues or input managers.

Implementations

Source

impl<'graph, 'ctx, 'clock, const OUT: usize, OutP, OutQ, OutM, C, T> OutStepContext<'graph, 'ctx, 'clock, OUT, OutP, OutQ, OutM, C, T>
where OutP: Payload, OutQ: Edge, OutM: MemoryManager<OutP>, C: PlatformClock + Sized, T: Telemetry + Sized,

pub fn out_try_push(&mut self, o: usize, m: Message<OutP>) -> EnqueueResult

Push a message to an output queue via the memory manager.

Stores the message in the manager, pushes the token to the edge, and handles eviction (frees evicted tokens from the manager).

pub fn out_occupancy(&mut self, o: usize) -> EdgeOccupancy

Snapshot occupancy for the given output edge.

pub fn out_policy(&mut self, o: usize) -> EdgePolicy

Return the policy for the given output (copy).

pub fn clock(&self) -> &C

Access the platform clock.

pub fn telemetry_mut(&mut self) -> &mut T

Borrow the telemetry sink.

pub fn now_ticks(&self) -> Ticks

Current monotonic tick value.

pub fn now_nanos(&self) -> u64

Current time in nanoseconds.

pub fn ticks_to_nanos(&self, t: Ticks) -> u64

Convert clock ticks to nanoseconds.

pub fn nanos_to_ticks(&self, ns: u64) -> Ticks

Convert nanoseconds to clock ticks.