WindowKind

Enum WindowKind 

#[non_exhaustive]
pub enum WindowKind { Disjoint, Sliding(SlidingWindow), }
How batches are formed over an input stream.

The window policy controls how items from a stream are grouped into Windows.

  • WindowKind::Disjoint (default): non-overlapping windows; each window consumes size items from the stream and the next window begins immediately after.
  • WindowKind::Sliding: fixed-size windows that advance by a fixed step. Each produced window contains size items, and the next window starts stride items after the previous window start. When stride == size, this is equivalent to WindowKind::Disjoint.

For WindowKind::Sliding, stride <= size is expected.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Disjoint

Non-overlapping (disjoint) windows; default.



Sliding(SlidingWindow)

Sliding windows: each produced window has size items and windows advance by stride items between steps.