Module runtime

Module runtime 

Runtime trait and stop-handle for Limen graph executors.

LimenRuntime is the uniform contract that all Limen runtimes implement. It owns a clock and telemetry after LimenRuntime::init and drives execution through LimenRuntime::step / LimenRuntime::run.

RuntimeStopHandle (std only) allows cooperative stop requests from outside the runtime loop (e.g. from another thread).

Modules

bench
(Work)bench test Runtime implementation.

Structs

RuntimeStopHandle
An opaque, cloneable, thread-safe stop handle for external cooperative stop.

Traits

LimenRuntime
A single, uniform runtime trait that all Limen runtimes (P0, P1, P2, P2Concurrent) can implement. The API is allocation- and threading-agnostic.