DequeuePolicy

Trait DequeuePolicy 

pub trait DequeuePolicy {
    // Required method
    fn select_next(&mut self, candidates: &[NodeSummary]) -> Option<NodeIndex>;
}
A dequeue policy selects the next node to run from a set of summaries.

Required Methods

fn select_next(&mut self, candidates: &[NodeSummary]) -> Option<NodeIndex>

Select the next node index to step, or None if none should run.

Implementors