spawn_telemetry_core

Function spawn_telemetry_core 

pub fn spawn_telemetry_core<T>(inner: T) -> TelemetryCoreHandle<T>
where T: Telemetry + Send + 'static,
Spawn a dedicated thread that owns inner and processes telemetry messages, returning a handle that can be used to obtain senders and shut the core down.