TelemetryCoreHandle

Struct TelemetryCoreHandle 

pub struct TelemetryCoreHandle<T: Telemetry> { /* private fields */ }
Handle returned by spawn_telemetry_core, owning the core thread and providing a clonable sender for worker threads.

Implementations

Source

impl<T: Telemetry> TelemetryCoreHandle<T>

pub fn sender(&self) -> TelemetrySender<T>

Return a clonable TelemetrySender<T> that can be passed to nodes.

pub fn shutdown_and_join(self)

Send a shutdown signal to the core and join the thread.

This should be called during runtime shutdown to ensure that all telemetry is flushed before exit.