TelemetrySender

Struct TelemetrySender 

pub struct TelemetrySender<T: Telemetry> { /* private fields */ }
Sender-side handle that implements Telemetry and forwards all calls to the core via a multi-producer, single-consumer channel.

Implementations

Source

impl<T: Telemetry> TelemetrySender<T>

pub fn send_shutdown(&self)

Send an explicit shutdown message to the telemetry core.

After this call, the core will exit its run loop once it processes the message and perform a final flush.