#[non_exhaustive]pub enum NodeStepError {
NoInput,
Backpressured,
OverBudget,
ExternalUnavailable,
ExecutionFailed,
}Expand description
High level classification of a node level error used in telemetry.
This mirrors crate::errors::NodeErrorKind so that telemetry can
faithfully report the scheduler-visible error semantics without
inventing additional information that is not available at this layer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoInput
Inputs were not available to progress this node.
Backpressured
Outputs could not be enqueued due to backpressure.
OverBudget
An execution budget or deadline was exceeded.
External dependency (device, transport) was unavailable or timed out.
ExecutionFailed
A generic failure in node logic.