#[non_exhaustive]pub enum TelemetryEvent {
NodeStep(NodeStepTelemetry),
EdgeSnapshot(EdgeSnapshotTelemetry),
Runtime(RuntimeTelemetryEvent),
}Expand description
Discriminated union of all structured telemetry events.
This is the type carried by event writers and is the payload for all structured telemetry emission.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NodeStep(NodeStepTelemetry)
Node level timing and throughput information for a single step.
EdgeSnapshot(EdgeSnapshotTelemetry)
Edge level snapshot representing queue state and watermarks.
Runtime(RuntimeTelemetryEvent)
Runtime level lifecycle and connectivity event.
Implementations
Sourceimpl TelemetryEvent
impl TelemetryEvent
Sourcepub const fn node_step(ev: NodeStepTelemetry) -> Self
pub const fn node_step(ev: NodeStepTelemetry) -> Self
Creates a telemetry event from a node step telemetry record.
Sourcepub const fn edge_snapshot(ev: EdgeSnapshotTelemetry) -> Self
pub const fn edge_snapshot(ev: EdgeSnapshotTelemetry) -> Self
Creates a telemetry event from an edge snapshot telemetry record.
Sourcepub const fn runtime(ev: RuntimeTelemetryEvent) -> Self
pub const fn runtime(ev: RuntimeTelemetryEvent) -> Self
Creates a telemetry event from a runtime telemetry event record.