#[non_exhaustive]pub enum TelemetryKind {
Processed,
Dropped,
DeadlineMiss,
QueueDepth,
Latency,
IngressMsgs,
EgressMsgs,
}Expand description
Logical kind of metric represented by a telemetry key.
These kinds are interpreted by collectors such as fixed and dynamic telemetry stores and are intentionally small and generic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Processed
Number of items successfully processed.
Dropped
Number of items dropped or discarded.
DeadlineMiss
Number of deadline misses observed.
QueueDepth
Current depth of a queue or buffer.
Latency
Latency measurement in nanoseconds.
IngressMsgs
Number of ingress messages received.
EgressMsgs
Number of egress messages emitted.