TelemetryNs

Enum TelemetryNs 

#[non_exhaustive]
pub enum TelemetryNs { Node, Edge, Runtime, }
Logical namespace for telemetry keys.

Separates metrics that describe nodes, edges, and the runtime itself.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Node

Node level metrics such as processed counts and latencies.



Edge

Edge level metrics such as queue depth.



Runtime

Runtime level metrics that are not tied to a particular node or edge.