TelemetrySinkError

Enum TelemetrySinkError 

#[non_exhaustive]
pub enum TelemetrySinkError { PushFailed, }
Error type returned by event writers when writing fails.

Implementations use this to signal input output failures or buffer exhaustion without tying the core telemetry code to any particular error type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PushFailed

The event could not be pushed to the underlying sink.