FmtLineWriter

Struct FmtLineWriter 

pub struct FmtLineWriter<W: Write> { /* private fields */ }
Event writer that formats events as lines of text using core::fmt::Write.

This is a no_std friendly sink that can write to any type that implements fmt::Write, such as a ring buffer or fixed size string.

Implementations

Source

impl<W: Write> FmtLineWriter<W>

pub fn new(writer: W) -> Self

Create a new line based event writer around the given writer.

pub fn inner(&self) -> &W

Access the inner fmt::Write target.