IoLineWriter

Struct IoLineWriter 

pub struct IoLineWriter<W: Write> { /* private fields */ }
Event writer that formats events as lines and writes them to a std::io::Write target.

This is a std only sink suitable for writing to files, sockets, or standard output without any heap allocation in the formatting path.

Implementations

Source

impl<W: Write> IoLineWriter<W>

pub fn new(writer: W) -> Self

Create a new input output backed event writer around the given writer.

pub fn stdout_writer() -> IoLineWriter<Stdout>

Create an IoLineWriter that writes telemetry lines to stdout.

pub fn file_writer(path: &str) -> Result<IoLineWriter<File>>

Create an IoLineWriter that writes telemetry lines to a file at path.