#[non_exhaustive]pub struct NodeStepTelemetry { /* private fields */ }Expand description
Structured telemetry produced for each node step.
A node step represents a single scheduling decision in which a node consumes zero or more input messages and produces zero or more output messages.
Implementations
Sourceimpl NodeStepTelemetry
impl NodeStepTelemetry
Sourcepub const fn new(
graph_id: GraphInstanceId,
node_index: NodeIndex,
node_name: Option<&'static str>,
timestamp_start_ns: u64,
timestamp_end_ns: u64,
duration_ns: u64,
processed_count: u64,
deadline_ns: Option<u64>,
deadline_missed: bool,
error_kind: Option<NodeStepError>,
) -> Self
pub const fn new( graph_id: GraphInstanceId, node_index: NodeIndex, node_name: Option<&'static str>, timestamp_start_ns: u64, timestamp_end_ns: u64, duration_ns: u64, processed_count: u64, deadline_ns: Option<u64>, deadline_missed: bool, error_kind: Option<NodeStepError>, ) -> Self
Construct a new NodeStepTelemetry record.
Sourcepub const fn graph_id(&self) -> &GraphInstanceId
pub const fn graph_id(&self) -> &GraphInstanceId
Returns the identifier of the graph instance this step belongs to.
Sourcepub const fn node_index(&self) -> &NodeIndex
pub const fn node_index(&self) -> &NodeIndex
Returns the index of the node within the graph.
Sourcepub const fn node_name(&self) -> &Option<&'static str>
pub const fn node_name(&self) -> &Option<&'static str>
Returns the optional static node name associated with this step.
Sourcepub const fn timestamp_start_ns(&self) -> &u64
pub const fn timestamp_start_ns(&self) -> &u64
Returns the step start timestamp in nanoseconds since an arbitrary epoch.
Sourcepub const fn timestamp_end_ns(&self) -> &u64
pub const fn timestamp_end_ns(&self) -> &u64
Returns the step end timestamp in nanoseconds since an arbitrary epoch.
Sourcepub const fn duration_ns(&self) -> &u64
pub const fn duration_ns(&self) -> &u64
Returns the step duration in nanoseconds.
Sourcepub const fn processed_count(&self) -> &u64
pub const fn processed_count(&self) -> &u64
Returns the number of messages processed by this step.
Sourcepub const fn deadline_ns(&self) -> &Option<u64>
pub const fn deadline_ns(&self) -> &Option<u64>
Returns the optional absolute deadline for this step in nanoseconds.
Sourcepub const fn deadline_missed(&self) -> &bool
pub const fn deadline_missed(&self) -> &bool
Returns whether the step exceeded its deadline.
Sourcepub const fn error_kind(&self) -> &Option<NodeStepError>
pub const fn error_kind(&self) -> &Option<NodeStepError>
Returns the optional high-level error classification for this step.