#[non_exhaustive]pub struct NodeError { /* private fields */ }Expand description
A unified error used by node lifecycle methods.
Implementations
Sourceimpl NodeError
impl NodeError
Sourcepub const fn new(kind: NodeErrorKind, code: u32) -> Self
pub const fn new(kind: NodeErrorKind, code: u32) -> Self
Construct a new node error with the given kind and optional code.
Sourceimpl NodeError
impl NodeError
Sourcepub const fn backpressured() -> Self
pub const fn backpressured() -> Self
Creates a Backpressured error.
Sourcepub const fn over_budget() -> Self
pub const fn over_budget() -> Self
Creates an OverBudget error.
Creates an ExternalUnavailable error.
Sourcepub const fn execution_failed() -> Self
pub const fn execution_failed() -> Self
Creates an ExecutionFailed error.
Sourcepub const fn with_code(self, code: u32) -> Self
pub const fn with_code(self, code: u32) -> Self
Same as the above but lets you tack on a backend/platform error code.
Sourcepub const fn kind(&self) -> &NodeErrorKind
pub const fn kind(&self) -> &NodeErrorKind
Return the error kind.