pub struct MessageFlags(/* private fields */);Expand description
A compact bitfield of message flags.
Implementations
Sourceimpl MessageFlags
impl MessageFlags
Sourcepub const FIRST_IN_BATCH: u32
pub const FIRST_IN_BATCH: u32
Flag: this message is the first element in a batch.
Sourcepub const LAST_IN_BATCH: u32
pub const LAST_IN_BATCH: u32
Flag: this message is the last element in a batch.
Sourcepub const DEGRADE_ALLOWED: u32
pub const DEGRADE_ALLOWED: u32
Flag: downstream may degrade this message (e.g., fast/low-precision path).
Sourcepub const fn first_in_batch(self) -> Self
pub const fn first_in_batch(self) -> Self
Return a copy with FIRST_IN_BATCH set.
Sourcepub const fn last_in_batch(self) -> Self
pub const fn last_in_batch(self) -> Self
Return a copy with LAST_IN_BATCH set.
Sourcepub const fn allow_degrade(self) -> Self
pub const fn allow_degrade(self) -> Self
Return a copy with DEGRADE_ALLOWED set.
Sourcepub const fn can_degrade(self) -> bool
pub const fn can_degrade(self) -> bool
true if DEGRADE_ALLOWED is set.