MessageHeader

Struct MessageHeader 

#[non_exhaustive]
pub struct MessageHeader { /* private fields */ }
Fixed header present on all messages that traverse the runtime.

Implementations

Source

impl MessageHeader

pub const fn new( trace_id: TraceId, sequence: SequenceNumber, creation_tick: Ticks, deadline_ns: Option<DeadlineNs>, qos: QoSClass, payload_size_bytes: usize, flags: MessageFlags, memory_class: MemoryClass, ) -> Self

Construct a new header.

pub const fn empty() -> Self

A zero/identity header (safe for scratch use).

pub fn is_empty(self) -> bool

Returns true is the message header is empty.

pub fn sync_from_payload<P: Payload>(&mut self, payload: &P)

Update payload_size_bytes and memory_class from a payload descriptor.

pub const fn trace_id(&self) -> &TraceId

Return the trace id.

pub fn set_trace_id(&mut self, trace_id: TraceId)

Set the trace id.

pub const fn sequence(&self) -> &SequenceNumber

Return the sequence number.

pub fn set_sequence(&mut self, sequence: SequenceNumber)

Set the sequence number.

pub const fn creation_tick(&self) -> &Ticks

Return the creation tick.

pub fn set_creation_tick(&mut self, creation_tick: Ticks)

Set the creation tick.

pub const fn deadline_ns(&self) -> &Option<DeadlineNs>

Return the optional deadline.

pub fn set_deadline_ns(&mut self, deadline_ns: Option<DeadlineNs>)

Set the optional deadline in nanoseconds since boot.

pub const fn qos(&self) -> &QoSClass

Return the QoS class.

pub fn set_qos(&mut self, qos: QoSClass)

Set the QoS class.

pub const fn payload_size_bytes(&self) -> &usize

Return the payload size in bytes.

pub fn set_payload_size_bytes(&mut self, payload_size_bytes: usize)

Set the payload size in bytes.

pub const fn flags(&self) -> &MessageFlags

Return the message flags.

pub fn set_flags(&mut self, flags: MessageFlags)

Set the message flags.

pub const fn memory_class(&self) -> &MemoryClass

Return the memory class.

pub fn set_memory_class(&mut self, memory_class: MemoryClass)

Set the memory class.

pub fn set_first_in_batch(&mut self)

Mark this header as the first element in a batch by setting FIRST_IN_BATCH.

pub fn set_last_in_batch(&mut self)

Mark this header as the last element in a batch by setting LAST_IN_BATCH.