Enum NodeKind Copy item path Source #[non_exhaustive]
pub enum NodeKind {
Source,
Process,
Model,
Split,
Join,
Sink,
External,
}Expand description Categories of nodes used in graph descriptors and builders.
These capture the high-level role of a node in the dataflow graph.
This enum is marked as non-exhaustive Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
A source node: 0 inputs / ≥1 outputs.
Examples: sensors, file readers, external ingress points.
A processing node: ≥1 inputs / ≥1 outputs.
Examples: stateless transforms, stateful operators, pre/post-processing.
A model node: ≥1 inputs / ≥1 outputs.
Represents inference nodes bound to a ComputeBackend and a model.
A split (fan-out) node: ≥1 inputs / ≥2 outputs.
Used to branch one stream into multiple downstream paths.
A join (fan-in) node: ≥2 inputs / ≥1 outputs.
Used to merge multiple streams into a single downstream path.
A sink node: ≥1 inputs / 0 outputs.
Examples: file writers, stdout, GPIO, MQTT, other terminal sinks.
An external node: request/response via transport to a remote or coprocessor.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.