Node graph-link descriptor types.
Structs
- Node
Descriptor - A node descriptor: topology and policy metadata, without an executable instance.
- Node
Link - A lightweight descriptor that links to a concrete node instance and records its static topology and policy metadata.