pub struct ConcurrentIngressEdgeLink<OutP: Payload> { /* private fields */ }Expand description
Link wrapper for a concurrent ingress monitor edge (std-only).
Implementations
Sourceimpl<OutP: Payload> ConcurrentIngressEdgeLink<OutP>
impl<OutP: Payload> ConcurrentIngressEdgeLink<OutP>
Sourcepub fn from_probe(
probe_edge: SourceIngressProbeEdge<OutP>,
id: EdgeIndex,
upstream: PortId,
downstream: PortId,
policy: EdgePolicy,
name: Option<&'static str>,
) -> Self
pub fn from_probe( probe_edge: SourceIngressProbeEdge<OutP>, id: EdgeIndex, upstream: PortId, downstream: PortId, policy: EdgePolicy, name: Option<&'static str>, ) -> Self
Construct a concurrent ingress edge link from a probe-backed edge and its descriptor metadata.
Sourcepub fn descriptor(&self) -> EdgeDescriptor
pub fn descriptor(&self) -> EdgeDescriptor
Return the descriptor for this synthetic ingress edge.
Sourcepub fn policy(&self) -> EdgePolicy
pub fn policy(&self) -> EdgePolicy
Return the policy associated with this synthetic ingress edge.
Sourcepub fn inner(&self) -> &SourceIngressProbeEdge<OutP>
pub fn inner(&self) -> &SourceIngressProbeEdge<OutP>
Borrow the inner probe-backed edge immutably.
Sourcepub fn inner_mut(&mut self) -> &mut SourceIngressProbeEdge<OutP>
pub fn inner_mut(&mut self) -> &mut SourceIngressProbeEdge<OutP>
Borrow the inner probe-backed edge mutably.