pub fn spawn_telemetry_core<T>(inner: T) -> TelemetryCoreHandle<T>Expand description
Spawn a dedicated thread that owns inner and processes telemetry messages,
returning a handle that can be used to obtain senders and shut the core down.
pub fn spawn_telemetry_core<T>(inner: T) -> TelemetryCoreHandle<T>Spawn a dedicated thread that owns inner and processes telemetry messages,
returning a handle that can be used to obtain senders and shut the core down.