pub struct FmtLineWriter<W: Write> { /* private fields */ }Expand description
Event writer that formats events as lines of text using core::fmt::Write.
This is a no_std friendly sink that can write to any type that implements
fmt::Write, such as a ring buffer or fixed size string.
Implementations